@@ -1,7 +1,5 @@
 package HTTP::Thin::UserAgent;
-{
-  $HTTP::Thin::UserAgent::VERSION = '0.007';
-}
+$HTTP::Thin::UserAgent::VERSION = '0.008';
 use 5.12.1;
 use warnings;
 
@@ -9,15 +7,16 @@ use warnings;
 
 {
 
-    package HTTP::Thin::UserAgent::Client;
-{
-  $HTTP::Thin::UserAgent::Client::VERSION = '0.007';
-}
+    package 
+        HTTP::Thin::UserAgent::Client;
+
     use Moo;
     use MooX::late;
     use HTTP::Thin;
     use JSON::Any;
     use Try::Tiny;
+    
+    use constant TRACE => $ENV{TRACE} // 0;
 
     use Throwable::Factory
       UnexpectedResponse => [qw($response)],
@@ -57,7 +56,13 @@ use warnings;
         my $self    = shift;
         my $ua      = $self->ua;
         my $request = $self->request;
-        return $ua->request($request);
+
+        return $ua->request($request) unless TRACE;
+            
+        warn $request->dump;
+        my $response = $ua->request($request);
+        warn $response->dump;
+        return $response;
     }
 
     sub as_json {
@@ -164,13 +169,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Thin::UserAgent - A Thin UserAgent around some useful modules.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -189,7 +196,7 @@ version 0.007
 
 =head1 DESCRIPTION
 
-WARNING this code is still *alpha* quality. While it will work as advertised on the tin, API breakage will likely be common until things settle down a bit. 
+WARNING this code is still *alpha* quality. While it will work as advertised on the tin, API breakage may occure as things settle.
 
 C<HTTP::Thin::UserAgent> provides what I hope is a thin layer over L<HTTP::Thin>. It exposes an functional API that hopefully makes writing HTTP clients easier. Right now it's in *very* alpha stage and really only helps for writing JSON clients. The intent is to expand it to be more generally useful but a JSON client was what I needed first.
 
@@ -211,7 +218,7 @@ Exports from L<Web::Scraper> to assist in building scrapers for HTML documents.
 
 =back
 
-=head1 Methods
+=head1 METHODS
 
 C<HTTP::Thin::UserAgent::Client> has the following methods.
 
@@ -247,6 +254,16 @@ A code reference that if there is an error in fetching the HTTP response handles
 
 =back
 
+=head1 ENVIRONMENT
+
+=over 4
+
+=item TRACE
+
+When set to true the C<TRACE> variable will cause C<HTTP::Thin::UserAgent::Client> to emit dumps of the request and response objects as it processes them. This is to help you in debugging the HTTP requests.
+
+=back
+
 =head1 AUTHOR
 
 Chris Prather <chris@prather.org>
